<img src="https://raw.githubusercontent.com/Autograders/logo/master/logo/full.png" width="145px" align="right" />

# Autograders Python3 Library

[![License](https://img.shields.io/github/license/autograders/lib)](https://github.com/Autograders/lib/blob/master/LICENSE) [![version](https://img.shields.io/pypi/v/pygraders)](https://pypi.org/project/pygraders/)
